@@ -31,12 +31,16 @@
 #include <errno.h>
 #include <termios.h>
 #include <sys/ioctl.h>
+#include <sys/socket.h>
 #include <unistd.h>
 
 #include "serial_class.h"
 
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_serial, "octave_serial", "octave_serial");
 
+DEFBINOP_CLASS_OP (eq_serial_serial, serial, serial, ==)
+DEFBINOP_CLASS_OP (ne_serial_serial, serial, serial, !=)
+
 octave_serial::octave_serial (void)
 : fd (-1)
 {
@@ -68,15 +72,17 @@ octave_serial::open (const std::string &path)
       // Check whether fd is an open file descriptor referring to a terminal
       if(! isatty (fd))
         {
-          error("serial: Interface does not refer to a terminal: %s\n", strerror (errno));
+          int err = errno;
           octave_serial::close ();
+          error("serial: Interface does not refer to a terminal: %s\n", strerror (err));
           return;
         }
 
       if (tcgetattr (fd, &config) < 0)
         {
-          error ("serial: Failed to get terminal attributes: %s\n", strerror (errno));
+          int err = errno;
           octave_serial::close ();
+          error ("serial: Failed to get terminal attributes: %s\n", strerror (err));
           return;
         }
 
@@ -89,16 +95,18 @@ octave_serial::open (const std::string &path)
 
       if (tcsetattr (fd, TCSANOW, &config) < 0)
         {
-            error ("serial: Failed to set default terminal attributes: %s\n", strerror (errno));
-            octave_serial::close ();
-            return;
+          int err = errno;
+          octave_serial::close ();
+          error ("serial: Failed to set default terminal attributes: %s\n", strerror (err));
+          return;
         }
 
         // Disable NDELAY
       if (fcntl (fd, F_SETFL, 0) < 0)
         {
-          error ("serial: Failed to disable NDELAY flag: %s\n", strerror (errno));
+          int err = errno;
           octave_serial::close ();
+          error ("serial: Failed to disable NDELAY flag: %s\n", strerror (err));
           return;
         }
 
@@ -193,7 +201,7 @@ octave_serial::set_timeout (short newtimeout)
       return -1;
     }
 
-  if (timeout < -1 || timeout > 255)
+  if (newtimeout < -1 || newtimeout > 255)
     {
       error("srl_timeout: timeout value must be between [-1..255]...");
       return -1;
@@ -550,6 +558,17 @@ octave_serial::flush (unsigned short queue_selector)
   return ::tcflush (fd, flag);
 }
 
+int
+octave_serial::sendbreak (unsigned short ms)
+{
+  if (! fd_is_valid ())
+    {
+      error ("serial: Interface must be opened first...");
+      return -1;
+    }
+
+  return ::tcsendbreak (fd, ms);
+}
 
 int
 octave_serial::set_parity (const std::string &newparity)
