@@ -104,6 +104,8 @@ Undocumented internal function.\n\
     {
       if (property == "name")
         return octave_value (udpport->get_name ());
+      else if (property == "tag")
+        return octave_value (udpport->get_tag ());
       else if (property == "type")
         return octave_value (udpport->get_type ());
       else if (property == "remoteport")
@@ -147,6 +149,8 @@ Undocumented internal function.\n\
     {
       if (property == "name")
         return octave_value (udpport->set_name (args(2).string_value ()));
+      else if (property == "tag")
+        { udpport->set_tag (args(2).string_value ()); return octave_value(); }
       else if (property == "type")
         (*current_liboctave_error_handler) ("can not set this property");
       else if (property == "localport")
