@@ -115,7 +115,7 @@ int to_ip_port (const sockaddr_in *in, std::string &ip, int &port)
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_udpport, "octave_udpport", "octave_udpport");
 
 octave_udpport::octave_udpport (void)
-: buffer_len(0), fd(-1), timeout(-1), name(""), fieldnames(17)
+: buffer_len(0), fd(-1), timeout(-1), name(""), fieldnames(18)
 {
   static bool type_registered = false;
 
@@ -150,6 +150,7 @@ octave_udpport::octave_udpport (void)
   fieldnames[14] = "EnablePortSharing";
   fieldnames[15] = "IPAddressVersion";
   fieldnames[16] = "Terminator";
+  fieldnames[17] = "Tag";
 }
 
 bool octave_udpport::has_property(const std::string &name) const
@@ -286,8 +287,9 @@ octave_udpport::open (const std::string &address, int port, int portshare)
 
   if (fd < 0)
     {
-      error ("udpport: error opening socket : %d - %s\n", SOCKETERR, STRSOCKETERR);
+      int err = SOCKETERR;
       octave_udpport::close ();
+      error ("udpport: error opening socket : %d - %s\n", err, STRSOCKETERR);
       return -1;
     }
 
@@ -315,8 +317,9 @@ octave_udpport::open (const std::string &address, int port, int portshare)
   sockerr = bind (fd, (struct sockaddr*)&local_addr, sizeof (local_addr));
   if (sockerr < 0)
     {
-      error ("udpport: error on bind : %d - %s\n", SOCKETERR, STRSOCKETERR);
+      int err = SOCKETERR;
       octave_udpport::close ();
+      error ("udpport: error on bind : %d - %s\n", err, STRSOCKETERR);
       return -1;
     }  
   else if (port == 0)
@@ -496,7 +499,7 @@ octave_udpport::read (uint8_t *buf, unsigned int len, double readtimeout, sockad
 	    {
               read_retval = len - bytes_read;
               memcpy(&buf[bytes_read], input_buffer, read_retval);
-              memcpy(&input_buffer[0], &input_buffer[read_retval], buffer_pos-read_retval);
+              memmove(&input_buffer[0], &input_buffer[read_retval], buffer_pos-read_retval);
               buffer_pos -= read_retval;
 
             }
